# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: powergate/user/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='powergate/user/v1/user.proto',
  package='powergate.user.v1',
  syntax='proto3',
  serialized_options=b'Z?github.com/textileio/powergate/api/gen/powergate/user/v1;userPb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cpowergate/user/v1/user.proto\x12\x11powergate.user.v1\"\x12\n\x10\x42uildInfoRequest\"\x88\x01\n\x11\x42uildInfoResponse\x12\x12\n\ngit_commit\x18\x01 \x01(\t\x12\x12\n\ngit_branch\x18\x02 \x01(\t\x12\x11\n\tgit_state\x18\x03 \x01(\t\x12\x13\n\x0bgit_summary\x18\x04 \x01(\t\x12\x12\n\nbuild_date\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\t\"\x17\n\x15UserIdentifierRequest\"$\n\x16UserIdentifierResponse\x12\n\n\x02id\x18\x01 \x01(\t\"\x1d\n\x1b\x44\x65\x66\x61ultStorageConfigRequest\"`\n\x1c\x44\x65\x66\x61ultStorageConfigResponse\x12@\n\x16\x64\x65\x66\x61ult_storage_config\x18\x01 \x01(\x0b\x32 .powergate.user.v1.StorageConfig\"R\n\x1eSetDefaultStorageConfigRequest\x12\x30\n\x06\x63onfig\x18\x01 \x01(\x0b\x32 .powergate.user.v1.StorageConfig\"!\n\x1fSetDefaultStorageConfigResponse\"\x1d\n\x0cStageRequest\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\x1c\n\rStageResponse\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\x1e\n\x0fStageCidRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\x12\n\x10StageCidResponse\"\xa4\x01\n\x19\x41pplyStorageConfigRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x30\n\x06\x63onfig\x18\x02 \x01(\x0b\x32 .powergate.user.v1.StorageConfig\x12\x12\n\nhas_config\x18\x03 \x01(\x08\x12\x17\n\x0foverride_config\x18\x04 \x01(\x08\x12\x1b\n\x13has_override_config\x18\x05 \x01(\x08\",\n\x1a\x41pplyStorageConfigResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"0\n\x12ReplaceDataRequest\x12\x0c\n\x04\x63id1\x18\x01 \x01(\t\x12\x0c\n\x04\x63id2\x18\x02 \x01(\t\"%\n\x13ReplaceDataResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x19\n\nGetRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\x1c\n\x0bGetResponse\x12\r\n\x05\x63hunk\x18\x01 \x01(\x0c\"\x1c\n\rRemoveRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\x10\n\x0eRemoveResponse\"@\n\x10WatchLogsRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x0f\n\x07history\x18\x03 \x01(\x08\"C\n\x11WatchLogsResponse\x12.\n\tlog_entry\x18\x01 \x01(\x0b\x32\x1b.powergate.user.v1.LogEntry\"\x1e\n\x0e\x43idInfoRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"@\n\x0f\x43idInfoResponse\x12-\n\tcid_infos\x18\x01 \x03(\x0b\x32\x1a.powergate.user.v1.CidInfo\"!\n\x0e\x42\x61lanceRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\"\n\x0f\x42\x61lanceResponse\x12\x0f\n\x07\x62\x61lance\x18\x01 \x01(\t\"M\n\x11NewAddressRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\t\x12\x14\n\x0cmake_default\x18\x03 \x01(\x08\"%\n\x12NewAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\x12\n\x10\x41\x64\x64ressesRequest\"C\n\x11\x41\x64\x64ressesResponse\x12.\n\taddresses\x18\x01 \x03(\x0b\x32\x1b.powergate.user.v1.AddrInfo\":\n\x0eSendFilRequest\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\"\x11\n\x0fSendFilResponse\"6\n\x12SignMessageRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\x0c\"(\n\x13SignMessageResponse\x12\x11\n\tsignature\x18\x01 \x01(\x0c\"K\n\x14VerifyMessageRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"#\n\x15VerifyMessageResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\")\n\x17\x43\x61ncelStorageJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x1a\n\x18\x43\x61ncelStorageJobResponse\"#\n\x11StorageJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"H\n\x12StorageJobResponse\x12\x32\n\x0bstorage_job\x18\x01 \x01(\x0b\x32\x1d.powergate.user.v1.StorageJob\",\n\x1aStorageConfigForJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"W\n\x1bStorageConfigForJobResponse\x12\x38\n\x0estorage_config\x18\x01 \x01(\x0b\x32 .powergate.user.v1.StorageConfig\"(\n\x18QueuedStorageJobsRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"P\n\x19QueuedStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"+\n\x1b\x45xecutingStorageJobsRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"S\n\x1c\x45xecutingStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"-\n\x1dLatestFinalStorageJobsRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"U\n\x1eLatestFinalStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"2\n\"LatestSuccessfulStorageJobsRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"Z\n#LatestSuccessfulStorageJobsResponse\x12\x33\n\x0cstorage_jobs\x18\x01 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\")\n\x19StorageJobsSummaryRequest\x12\x0c\n\x04\x63ids\x18\x01 \x03(\t\"\xd2\x02\n\x1aStorageJobsSummaryResponse\x12\x30\n\njob_counts\x18\x01 \x01(\x0b\x32\x1c.powergate.user.v1.JobCounts\x12:\n\x13queued_storage_jobs\x18\x02 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12=\n\x16\x65xecuting_storage_jobs\x18\x03 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12@\n\x19latest_final_storage_jobs\x18\x04 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12\x45\n\x1elatest_successful_storage_jobs\x18\x05 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\"*\n\x17WatchStorageJobsRequest\x12\x0f\n\x07job_ids\x18\x01 \x03(\t\"N\n\x18WatchStorageJobsResponse\x12\x32\n\x0bstorage_job\x18\x01 \x01(\x0b\x32\x1d.powergate.user.v1.StorageJob\"Q\n\x19StorageDealRecordsRequest\x12\x34\n\x06\x63onfig\x18\x01 \x01(\x0b\x32$.powergate.user.v1.DealRecordsConfig\"S\n\x1aStorageDealRecordsResponse\x12\x35\n\x07records\x18\x01 \x03(\x0b\x32$.powergate.user.v1.StorageDealRecord\"S\n\x1bRetrievalDealRecordsRequest\x12\x34\n\x06\x63onfig\x18\x01 \x01(\x0b\x32$.powergate.user.v1.DealRecordsConfig\"W\n\x1cRetrievalDealRecordsResponse\x12\x37\n\x07records\x18\x01 \x03(\x0b\x32&.powergate.user.v1.RetrievalDealRecord\"_\n\tJobCounts\x12\x0e\n\x06queued\x18\x01 \x01(\x05\x12\x11\n\texecuting\x18\x02 \x01(\x05\x12\x14\n\x0clatest_final\x18\x03 \x01(\x05\x12\x19\n\x11latest_successful\x18\x04 \x01(\x05\"H\n\x08\x41\x64\x64rInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x04 \x01(\t\"!\n\nIpfsConfig\x12\x13\n\x0b\x61\x64\x64_timeout\x18\x01 \x01(\x03\"}\n\tHotConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x16\n\x0e\x61llow_unfreeze\x18\x02 \x01(\x08\x12\x1a\n\x12unfreeze_max_price\x18\x03 \x01(\x04\x12+\n\x04ipfs\x18\x04 \x01(\x0b\x32\x1d.powergate.user.v1.IpfsConfig\".\n\x08\x46ilRenew\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x11\n\tthreshold\x18\x02 \x01(\x03\"\x8d\x02\n\tFilConfig\x12\x1a\n\x12replication_factor\x18\x01 \x01(\x03\x12\x19\n\x11\x64\x65\x61l_min_duration\x18\x02 \x01(\x03\x12\x17\n\x0f\x65xcluded_miners\x18\x03 \x03(\t\x12\x16\n\x0etrusted_miners\x18\x04 \x03(\t\x12\x15\n\rcountry_codes\x18\x05 \x03(\t\x12*\n\x05renew\x18\x06 \x01(\x0b\x32\x1b.powergate.user.v1.FilRenew\x12\x0f\n\x07\x61\x64\x64ress\x18\x07 \x01(\t\x12\x11\n\tmax_price\x18\x08 \x01(\x04\x12\x16\n\x0e\x66\x61st_retrieval\x18\t \x01(\x08\x12\x19\n\x11\x64\x65\x61l_start_offset\x18\n \x01(\x03\"M\n\nColdConfig\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12.\n\x08\x66ilecoin\x18\x02 \x01(\x0b\x32\x1c.powergate.user.v1.FilConfig\"{\n\rStorageConfig\x12)\n\x03hot\x18\x01 \x01(\x0b\x32\x1c.powergate.user.v1.HotConfig\x12+\n\x04\x63old\x18\x02 \x01(\x0b\x32\x1d.powergate.user.v1.ColdConfig\x12\x12\n\nrepairable\x18\x03 \x01(\x08\"\x1e\n\x0bIpfsHotInfo\x12\x0f\n\x07\x63reated\x18\x01 \x01(\x03\"V\n\x07HotInfo\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04size\x18\x02 \x01(\x03\x12,\n\x04ipfs\x18\x03 \x01(\x0b\x32\x1e.powergate.user.v1.IpfsHotInfo\"\xab\x01\n\nFilStorage\x12\x14\n\x0cproposal_cid\x18\x01 \x01(\t\x12\x0f\n\x07renewed\x18\x02 \x01(\x08\x12\x10\n\x08\x64uration\x18\x03 \x01(\x03\x12\x18\n\x10\x61\x63tivation_epoch\x18\x04 \x01(\x03\x12\x13\n\x0bstart_epoch\x18\x05 \x01(\x04\x12\r\n\x05miner\x18\x06 \x01(\t\x12\x13\n\x0b\x65poch_price\x18\x07 \x01(\x04\x12\x11\n\tpiece_cid\x18\x08 \x01(\t\"[\n\x07\x46ilInfo\x12\x10\n\x08\x64\x61ta_cid\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x30\n\tproposals\x18\x03 \x03(\x0b\x32\x1d.powergate.user.v1.FilStorage\"I\n\x08\x43oldInfo\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12,\n\x08\x66ilecoin\x18\x02 \x01(\x0b\x32\x1a.powergate.user.v1.FilInfo\"\x8f\x01\n\x0bStorageInfo\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0b\n\x03\x63id\x18\x02 \x01(\t\x12\x0f\n\x07\x63reated\x18\x03 \x01(\x03\x12\'\n\x03hot\x18\x04 \x01(\x0b\x32\x1a.powergate.user.v1.HotInfo\x12)\n\x04\x63old\x18\x05 \x01(\x0b\x32\x1b.powergate.user.v1.ColdInfo\"\x9d\x03\n\x07\x43idInfo\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x46\n\x1clatest_pushed_storage_config\x18\x02 \x01(\x0b\x32 .powergate.user.v1.StorageConfig\x12<\n\x14\x63urrent_storage_info\x18\x03 \x01(\x0b\x32\x1e.powergate.user.v1.StorageInfo\x12:\n\x13queued_storage_jobs\x18\x04 \x03(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12<\n\x15\x65xecuting_storage_job\x18\x05 \x01(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12?\n\x18latest_final_storage_job\x18\x06 \x01(\x0b\x32\x1d.powergate.user.v1.StorageJob\x12\x44\n\x1dlatest_successful_storage_job\x18\x07 \x01(\x0b\x32\x1d.powergate.user.v1.StorageJob\"\xf2\x01\n\x08\x44\x65\x61lInfo\x12\x14\n\x0cproposal_cid\x18\x01 \x01(\t\x12\x10\n\x08state_id\x18\x02 \x01(\x04\x12\x12\n\nstate_name\x18\x03 \x01(\t\x12\r\n\x05miner\x18\x04 \x01(\t\x12\x11\n\tpiece_cid\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x17\n\x0fprice_per_epoch\x18\x07 \x01(\x04\x12\x13\n\x0bstart_epoch\x18\x08 \x01(\x04\x12\x10\n\x08\x64uration\x18\t \x01(\x04\x12\x0f\n\x07\x64\x65\x61l_id\x18\n \x01(\x04\x12\x18\n\x10\x61\x63tivation_epoch\x18\x0b \x01(\x03\x12\x0f\n\x07message\x18\x0c \x01(\t\"\xef\x01\n\nStorageJob\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pi_id\x18\x02 \x01(\t\x12\x0b\n\x03\x63id\x18\x03 \x01(\t\x12,\n\x06status\x18\x04 \x01(\x0e\x32\x1c.powergate.user.v1.JobStatus\x12\x13\n\x0b\x65rror_cause\x18\x05 \x01(\t\x12.\n\tdeal_info\x18\x06 \x03(\x0b\x32\x1b.powergate.user.v1.DealInfo\x12\x31\n\x0b\x64\x65\x61l_errors\x18\x07 \x03(\x0b\x32\x1c.powergate.user.v1.DealError\x12\x12\n\ncreated_at\x18\x08 \x01(\x03\"A\n\tDealError\x12\x14\n\x0cproposal_cid\x18\x01 \x01(\t\x12\r\n\x05miner\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t\"F\n\x08LogEntry\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x12\x0f\n\x07message\x18\x04 \x01(\t\"}\n\x11\x44\x65\x61lRecordsConfig\x12\x12\n\nfrom_addrs\x18\x01 \x03(\t\x12\x11\n\tdata_cids\x18\x02 \x03(\t\x12\x17\n\x0finclude_pending\x18\x03 \x01(\x08\x12\x15\n\rinclude_final\x18\x04 \x01(\x08\x12\x11\n\tascending\x18\x05 \x01(\x08\"\xf9\x01\n\x0fStorageDealInfo\x12\x14\n\x0cproposal_cid\x18\x01 \x01(\t\x12\x10\n\x08state_id\x18\x02 \x01(\x04\x12\x12\n\nstate_name\x18\x03 \x01(\t\x12\r\n\x05miner\x18\x04 \x01(\t\x12\x11\n\tpiece_cid\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x04\x12\x17\n\x0fprice_per_epoch\x18\x07 \x01(\x04\x12\x13\n\x0bstart_epoch\x18\x08 \x01(\x04\x12\x10\n\x08\x64uration\x18\t \x01(\x04\x12\x0f\n\x07\x64\x65\x61l_id\x18\n \x01(\x04\x12\x18\n\x10\x61\x63tivation_epoch\x18\x0b \x01(\x03\x12\x0f\n\x07message\x18\x0c \x01(\t\"\x8c\x01\n\x11StorageDealRecord\x12\x10\n\x08root_cid\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04time\x18\x03 \x01(\x03\x12\x0f\n\x07pending\x18\x04 \x01(\x08\x12\x35\n\tdeal_info\x18\x05 \x01(\x0b\x32\".powergate.user.v1.StorageDealInfo\"\xa9\x01\n\x11RetrievalDealInfo\x12\x10\n\x08root_cid\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x04\x12\x11\n\tmin_price\x18\x03 \x01(\x04\x12\x18\n\x10payment_interval\x18\x04 \x01(\x04\x12!\n\x19payment_interval_increase\x18\x05 \x01(\x04\x12\r\n\x05miner\x18\x06 \x01(\t\x12\x15\n\rminer_peer_id\x18\x07 \x01(\t\"m\n\x13RetrievalDealRecord\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04time\x18\x02 \x01(\x03\x12\x37\n\tdeal_info\x18\x03 \x01(\x0b\x32$.powergate.user.v1.RetrievalDealInfo*\xa0\x01\n\tJobStatus\x12\x1a\n\x16JOB_STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11JOB_STATUS_QUEUED\x10\x01\x12\x18\n\x14JOB_STATUS_EXECUTING\x10\x02\x12\x15\n\x11JOB_STATUS_FAILED\x10\x03\x12\x17\n\x13JOB_STATUS_CANCELED\x10\x04\x12\x16\n\x12JOB_STATUS_SUCCESS\x10\x05\x32\xd5\x17\n\x0bUserService\x12X\n\tBuildInfo\x12#.powergate.user.v1.BuildInfoRequest\x1a$.powergate.user.v1.BuildInfoResponse\"\x00\x12g\n\x0eUserIdentifier\x12(.powergate.user.v1.UserIdentifierRequest\x1a).powergate.user.v1.UserIdentifierResponse\"\x00\x12y\n\x14\x44\x65\x66\x61ultStorageConfig\x12..powergate.user.v1.DefaultStorageConfigRequest\x1a/.powergate.user.v1.DefaultStorageConfigResponse\"\x00\x12\x82\x01\n\x17SetDefaultStorageConfig\x12\x31.powergate.user.v1.SetDefaultStorageConfigRequest\x1a\x32.powergate.user.v1.SetDefaultStorageConfigResponse\"\x00\x12s\n\x12\x41pplyStorageConfig\x12,.powergate.user.v1.ApplyStorageConfigRequest\x1a-.powergate.user.v1.ApplyStorageConfigResponse\"\x00\x12O\n\x06Remove\x12 .powergate.user.v1.RemoveRequest\x1a!.powergate.user.v1.RemoveResponse\"\x00\x12N\n\x05Stage\x12\x1f.powergate.user.v1.StageRequest\x1a .powergate.user.v1.StageResponse\"\x00(\x01\x12U\n\x08StageCid\x12\".powergate.user.v1.StageCidRequest\x1a#.powergate.user.v1.StageCidResponse\"\x00\x12^\n\x0bReplaceData\x12%.powergate.user.v1.ReplaceDataRequest\x1a&.powergate.user.v1.ReplaceDataResponse\"\x00\x12H\n\x03Get\x12\x1d.powergate.user.v1.GetRequest\x1a\x1e.powergate.user.v1.GetResponse\"\x00\x30\x01\x12Z\n\tWatchLogs\x12#.powergate.user.v1.WatchLogsRequest\x1a$.powergate.user.v1.WatchLogsResponse\"\x00\x30\x01\x12R\n\x07\x43idInfo\x12!.powergate.user.v1.CidInfoRequest\x1a\".powergate.user.v1.CidInfoResponse\"\x00\x12R\n\x07\x42\x61lance\x12!.powergate.user.v1.BalanceRequest\x1a\".powergate.user.v1.BalanceResponse\"\x00\x12[\n\nNewAddress\x12$.powergate.user.v1.NewAddressRequest\x1a%.powergate.user.v1.NewAddressResponse\"\x00\x12X\n\tAddresses\x12#.powergate.user.v1.AddressesRequest\x1a$.powergate.user.v1.AddressesResponse\"\x00\x12R\n\x07SendFil\x12!.powergate.user.v1.SendFilRequest\x1a\".powergate.user.v1.SendFilResponse\"\x00\x12^\n\x0bSignMessage\x12%.powergate.user.v1.SignMessageRequest\x1a&.powergate.user.v1.SignMessageResponse\"\x00\x12\x64\n\rVerifyMessage\x12\'.powergate.user.v1.VerifyMessageRequest\x1a(.powergate.user.v1.VerifyMessageResponse\"\x00\x12[\n\nStorageJob\x12$.powergate.user.v1.StorageJobRequest\x1a%.powergate.user.v1.StorageJobResponse\"\x00\x12v\n\x13StorageConfigForJob\x12-.powergate.user.v1.StorageConfigForJobRequest\x1a..powergate.user.v1.StorageConfigForJobResponse\"\x00\x12p\n\x11QueuedStorageJobs\x12+.powergate.user.v1.QueuedStorageJobsRequest\x1a,.powergate.user.v1.QueuedStorageJobsResponse\"\x00\x12y\n\x14\x45xecutingStorageJobs\x12..powergate.user.v1.ExecutingStorageJobsRequest\x1a/.powergate.user.v1.ExecutingStorageJobsResponse\"\x00\x12\x7f\n\x16LatestFinalStorageJobs\x12\x30.powergate.user.v1.LatestFinalStorageJobsRequest\x1a\x31.powergate.user.v1.LatestFinalStorageJobsResponse\"\x00\x12\x8e\x01\n\x1bLatestSuccessfulStorageJobs\x12\x35.powergate.user.v1.LatestSuccessfulStorageJobsRequest\x1a\x36.powergate.user.v1.LatestSuccessfulStorageJobsResponse\"\x00\x12s\n\x12StorageJobsSummary\x12,.powergate.user.v1.StorageJobsSummaryRequest\x1a-.powergate.user.v1.StorageJobsSummaryResponse\"\x00\x12o\n\x10WatchStorageJobs\x12*.powergate.user.v1.WatchStorageJobsRequest\x1a+.powergate.user.v1.WatchStorageJobsResponse\"\x00\x30\x01\x12m\n\x10\x43\x61ncelStorageJob\x12*.powergate.user.v1.CancelStorageJobRequest\x1a+.powergate.user.v1.CancelStorageJobResponse\"\x00\x12s\n\x12StorageDealRecords\x12,.powergate.user.v1.StorageDealRecordsRequest\x1a-.powergate.user.v1.StorageDealRecordsResponse\"\x00\x12y\n\x14RetrievalDealRecords\x12..powergate.user.v1.RetrievalDealRecordsRequest\x1a/.powergate.user.v1.RetrievalDealRecordsResponse\"\x00\x42\x41Z?github.com/textileio/powergate/api/gen/powergate/user/v1;userPbb\x06proto3'
)

_JOBSTATUS = _descriptor.EnumDescriptor(
  name='JobStatus',
  full_name='powergate.user.v1.JobStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_QUEUED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_EXECUTING', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_FAILED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_CANCELED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JOB_STATUS_SUCCESS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6855,
  serialized_end=7015,
)
_sym_db.RegisterEnumDescriptor(_JOBSTATUS)

JobStatus = enum_type_wrapper.EnumTypeWrapper(_JOBSTATUS)
JOB_STATUS_UNSPECIFIED = 0
JOB_STATUS_QUEUED = 1
JOB_STATUS_EXECUTING = 2
JOB_STATUS_FAILED = 3
JOB_STATUS_CANCELED = 4
JOB_STATUS_SUCCESS = 5



_BUILDINFOREQUEST = _descriptor.Descriptor(
  name='BuildInfoRequest',
  full_name='powergate.user.v1.BuildInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=69,
)


_BUILDINFORESPONSE = _descriptor.Descriptor(
  name='BuildInfoResponse',
  full_name='powergate.user.v1.BuildInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='git_commit', full_name='powergate.user.v1.BuildInfoResponse.git_commit', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_branch', full_name='powergate.user.v1.BuildInfoResponse.git_branch', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_state', full_name='powergate.user.v1.BuildInfoResponse.git_state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='git_summary', full_name='powergate.user.v1.BuildInfoResponse.git_summary', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build_date', full_name='powergate.user.v1.BuildInfoResponse.build_date', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='powergate.user.v1.BuildInfoResponse.version', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=72,
  serialized_end=208,
)


_USERIDENTIFIERREQUEST = _descriptor.Descriptor(
  name='UserIdentifierRequest',
  full_name='powergate.user.v1.UserIdentifierRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=233,
)


_USERIDENTIFIERRESPONSE = _descriptor.Descriptor(
  name='UserIdentifierResponse',
  full_name='powergate.user.v1.UserIdentifierResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='powergate.user.v1.UserIdentifierResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=271,
)


_DEFAULTSTORAGECONFIGREQUEST = _descriptor.Descriptor(
  name='DefaultStorageConfigRequest',
  full_name='powergate.user.v1.DefaultStorageConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=302,
)


_DEFAULTSTORAGECONFIGRESPONSE = _descriptor.Descriptor(
  name='DefaultStorageConfigResponse',
  full_name='powergate.user.v1.DefaultStorageConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_storage_config', full_name='powergate.user.v1.DefaultStorageConfigResponse.default_storage_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=304,
  serialized_end=400,
)


_SETDEFAULTSTORAGECONFIGREQUEST = _descriptor.Descriptor(
  name='SetDefaultStorageConfigRequest',
  full_name='powergate.user.v1.SetDefaultStorageConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='powergate.user.v1.SetDefaultStorageConfigRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=484,
)


_SETDEFAULTSTORAGECONFIGRESPONSE = _descriptor.Descriptor(
  name='SetDefaultStorageConfigResponse',
  full_name='powergate.user.v1.SetDefaultStorageConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=519,
)


_STAGEREQUEST = _descriptor.Descriptor(
  name='StageRequest',
  full_name='powergate.user.v1.StageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunk', full_name='powergate.user.v1.StageRequest.chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=550,
)


_STAGERESPONSE = _descriptor.Descriptor(
  name='StageResponse',
  full_name='powergate.user.v1.StageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.StageResponse.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=552,
  serialized_end=580,
)


_STAGECIDREQUEST = _descriptor.Descriptor(
  name='StageCidRequest',
  full_name='powergate.user.v1.StageCidRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.StageCidRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=612,
)


_STAGECIDRESPONSE = _descriptor.Descriptor(
  name='StageCidResponse',
  full_name='powergate.user.v1.StageCidResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=632,
)


_APPLYSTORAGECONFIGREQUEST = _descriptor.Descriptor(
  name='ApplyStorageConfigRequest',
  full_name='powergate.user.v1.ApplyStorageConfigRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.ApplyStorageConfigRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config', full_name='powergate.user.v1.ApplyStorageConfigRequest.config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_config', full_name='powergate.user.v1.ApplyStorageConfigRequest.has_config', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='override_config', full_name='powergate.user.v1.ApplyStorageConfigRequest.override_config', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_override_config', full_name='powergate.user.v1.ApplyStorageConfigRequest.has_override_config', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=635,
  serialized_end=799,
)


_APPLYSTORAGECONFIGRESPONSE = _descriptor.Descriptor(
  name='ApplyStorageConfigResponse',
  full_name='powergate.user.v1.ApplyStorageConfigResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.ApplyStorageConfigResponse.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=801,
  serialized_end=845,
)


_REPLACEDATAREQUEST = _descriptor.Descriptor(
  name='ReplaceDataRequest',
  full_name='powergate.user.v1.ReplaceDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid1', full_name='powergate.user.v1.ReplaceDataRequest.cid1', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid2', full_name='powergate.user.v1.ReplaceDataRequest.cid2', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=847,
  serialized_end=895,
)


_REPLACEDATARESPONSE = _descriptor.Descriptor(
  name='ReplaceDataResponse',
  full_name='powergate.user.v1.ReplaceDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.ReplaceDataResponse.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=897,
  serialized_end=934,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='powergate.user.v1.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.GetRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=936,
  serialized_end=961,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='powergate.user.v1.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='chunk', full_name='powergate.user.v1.GetResponse.chunk', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=991,
)


_REMOVEREQUEST = _descriptor.Descriptor(
  name='RemoveRequest',
  full_name='powergate.user.v1.RemoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.RemoveRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=993,
  serialized_end=1021,
)


_REMOVERESPONSE = _descriptor.Descriptor(
  name='RemoveResponse',
  full_name='powergate.user.v1.RemoveResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1023,
  serialized_end=1039,
)


_WATCHLOGSREQUEST = _descriptor.Descriptor(
  name='WatchLogsRequest',
  full_name='powergate.user.v1.WatchLogsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.WatchLogsRequest.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.WatchLogsRequest.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history', full_name='powergate.user.v1.WatchLogsRequest.history', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1041,
  serialized_end=1105,
)


_WATCHLOGSRESPONSE = _descriptor.Descriptor(
  name='WatchLogsResponse',
  full_name='powergate.user.v1.WatchLogsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log_entry', full_name='powergate.user.v1.WatchLogsResponse.log_entry', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1107,
  serialized_end=1174,
)


_CIDINFOREQUEST = _descriptor.Descriptor(
  name='CidInfoRequest',
  full_name='powergate.user.v1.CidInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.CidInfoRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1206,
)


_CIDINFORESPONSE = _descriptor.Descriptor(
  name='CidInfoResponse',
  full_name='powergate.user.v1.CidInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid_infos', full_name='powergate.user.v1.CidInfoResponse.cid_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1208,
  serialized_end=1272,
)


_BALANCEREQUEST = _descriptor.Descriptor(
  name='BalanceRequest',
  full_name='powergate.user.v1.BalanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.BalanceRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1274,
  serialized_end=1307,
)


_BALANCERESPONSE = _descriptor.Descriptor(
  name='BalanceResponse',
  full_name='powergate.user.v1.BalanceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='powergate.user.v1.BalanceResponse.balance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1343,
)


_NEWADDRESSREQUEST = _descriptor.Descriptor(
  name='NewAddressRequest',
  full_name='powergate.user.v1.NewAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='powergate.user.v1.NewAddressRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address_type', full_name='powergate.user.v1.NewAddressRequest.address_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='make_default', full_name='powergate.user.v1.NewAddressRequest.make_default', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1345,
  serialized_end=1422,
)


_NEWADDRESSRESPONSE = _descriptor.Descriptor(
  name='NewAddressResponse',
  full_name='powergate.user.v1.NewAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.NewAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1461,
)


_ADDRESSESREQUEST = _descriptor.Descriptor(
  name='AddressesRequest',
  full_name='powergate.user.v1.AddressesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1463,
  serialized_end=1481,
)


_ADDRESSESRESPONSE = _descriptor.Descriptor(
  name='AddressesResponse',
  full_name='powergate.user.v1.AddressesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addresses', full_name='powergate.user.v1.AddressesResponse.addresses', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1483,
  serialized_end=1550,
)


_SENDFILREQUEST = _descriptor.Descriptor(
  name='SendFilRequest',
  full_name='powergate.user.v1.SendFilRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='powergate.user.v1.SendFilRequest.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to', full_name='powergate.user.v1.SendFilRequest.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='powergate.user.v1.SendFilRequest.amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1552,
  serialized_end=1610,
)


_SENDFILRESPONSE = _descriptor.Descriptor(
  name='SendFilResponse',
  full_name='powergate.user.v1.SendFilResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1612,
  serialized_end=1629,
)


_SIGNMESSAGEREQUEST = _descriptor.Descriptor(
  name='SignMessageRequest',
  full_name='powergate.user.v1.SignMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.SignMessageRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.SignMessageRequest.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1685,
)


_SIGNMESSAGERESPONSE = _descriptor.Descriptor(
  name='SignMessageResponse',
  full_name='powergate.user.v1.SignMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='powergate.user.v1.SignMessageResponse.signature', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1687,
  serialized_end=1727,
)


_VERIFYMESSAGEREQUEST = _descriptor.Descriptor(
  name='VerifyMessageRequest',
  full_name='powergate.user.v1.VerifyMessageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.VerifyMessageRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.VerifyMessageRequest.message', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='powergate.user.v1.VerifyMessageRequest.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1804,
)


_VERIFYMESSAGERESPONSE = _descriptor.Descriptor(
  name='VerifyMessageResponse',
  full_name='powergate.user.v1.VerifyMessageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='powergate.user.v1.VerifyMessageResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1806,
  serialized_end=1841,
)


_CANCELSTORAGEJOBREQUEST = _descriptor.Descriptor(
  name='CancelStorageJobRequest',
  full_name='powergate.user.v1.CancelStorageJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.CancelStorageJobRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1843,
  serialized_end=1884,
)


_CANCELSTORAGEJOBRESPONSE = _descriptor.Descriptor(
  name='CancelStorageJobResponse',
  full_name='powergate.user.v1.CancelStorageJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1886,
  serialized_end=1912,
)


_STORAGEJOBREQUEST = _descriptor.Descriptor(
  name='StorageJobRequest',
  full_name='powergate.user.v1.StorageJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.StorageJobRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1914,
  serialized_end=1949,
)


_STORAGEJOBRESPONSE = _descriptor.Descriptor(
  name='StorageJobResponse',
  full_name='powergate.user.v1.StorageJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_job', full_name='powergate.user.v1.StorageJobResponse.storage_job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2023,
)


_STORAGECONFIGFORJOBREQUEST = _descriptor.Descriptor(
  name='StorageConfigForJobRequest',
  full_name='powergate.user.v1.StorageConfigForJobRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.StorageConfigForJobRequest.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2025,
  serialized_end=2069,
)


_STORAGECONFIGFORJOBRESPONSE = _descriptor.Descriptor(
  name='StorageConfigForJobResponse',
  full_name='powergate.user.v1.StorageConfigForJobResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_config', full_name='powergate.user.v1.StorageConfigForJobResponse.storage_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2071,
  serialized_end=2158,
)


_QUEUEDSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='QueuedStorageJobsRequest',
  full_name='powergate.user.v1.QueuedStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.QueuedStorageJobsRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2160,
  serialized_end=2200,
)


_QUEUEDSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='QueuedStorageJobsResponse',
  full_name='powergate.user.v1.QueuedStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.user.v1.QueuedStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2202,
  serialized_end=2282,
)


_EXECUTINGSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='ExecutingStorageJobsRequest',
  full_name='powergate.user.v1.ExecutingStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.ExecutingStorageJobsRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2284,
  serialized_end=2327,
)


_EXECUTINGSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='ExecutingStorageJobsResponse',
  full_name='powergate.user.v1.ExecutingStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.user.v1.ExecutingStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2329,
  serialized_end=2412,
)


_LATESTFINALSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='LatestFinalStorageJobsRequest',
  full_name='powergate.user.v1.LatestFinalStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.LatestFinalStorageJobsRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2414,
  serialized_end=2459,
)


_LATESTFINALSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='LatestFinalStorageJobsResponse',
  full_name='powergate.user.v1.LatestFinalStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.user.v1.LatestFinalStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2461,
  serialized_end=2546,
)


_LATESTSUCCESSFULSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='LatestSuccessfulStorageJobsRequest',
  full_name='powergate.user.v1.LatestSuccessfulStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.LatestSuccessfulStorageJobsRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2548,
  serialized_end=2598,
)


_LATESTSUCCESSFULSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='LatestSuccessfulStorageJobsResponse',
  full_name='powergate.user.v1.LatestSuccessfulStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_jobs', full_name='powergate.user.v1.LatestSuccessfulStorageJobsResponse.storage_jobs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2600,
  serialized_end=2690,
)


_STORAGEJOBSSUMMARYREQUEST = _descriptor.Descriptor(
  name='StorageJobsSummaryRequest',
  full_name='powergate.user.v1.StorageJobsSummaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cids', full_name='powergate.user.v1.StorageJobsSummaryRequest.cids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2692,
  serialized_end=2733,
)


_STORAGEJOBSSUMMARYRESPONSE = _descriptor.Descriptor(
  name='StorageJobsSummaryResponse',
  full_name='powergate.user.v1.StorageJobsSummaryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_counts', full_name='powergate.user.v1.StorageJobsSummaryResponse.job_counts', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queued_storage_jobs', full_name='powergate.user.v1.StorageJobsSummaryResponse.queued_storage_jobs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executing_storage_jobs', full_name='powergate.user.v1.StorageJobsSummaryResponse.executing_storage_jobs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_final_storage_jobs', full_name='powergate.user.v1.StorageJobsSummaryResponse.latest_final_storage_jobs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_successful_storage_jobs', full_name='powergate.user.v1.StorageJobsSummaryResponse.latest_successful_storage_jobs', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2736,
  serialized_end=3074,
)


_WATCHSTORAGEJOBSREQUEST = _descriptor.Descriptor(
  name='WatchStorageJobsRequest',
  full_name='powergate.user.v1.WatchStorageJobsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_ids', full_name='powergate.user.v1.WatchStorageJobsRequest.job_ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3118,
)


_WATCHSTORAGEJOBSRESPONSE = _descriptor.Descriptor(
  name='WatchStorageJobsResponse',
  full_name='powergate.user.v1.WatchStorageJobsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_job', full_name='powergate.user.v1.WatchStorageJobsResponse.storage_job', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3120,
  serialized_end=3198,
)


_STORAGEDEALRECORDSREQUEST = _descriptor.Descriptor(
  name='StorageDealRecordsRequest',
  full_name='powergate.user.v1.StorageDealRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='powergate.user.v1.StorageDealRecordsRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3200,
  serialized_end=3281,
)


_STORAGEDEALRECORDSRESPONSE = _descriptor.Descriptor(
  name='StorageDealRecordsResponse',
  full_name='powergate.user.v1.StorageDealRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='powergate.user.v1.StorageDealRecordsResponse.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3283,
  serialized_end=3366,
)


_RETRIEVALDEALRECORDSREQUEST = _descriptor.Descriptor(
  name='RetrievalDealRecordsRequest',
  full_name='powergate.user.v1.RetrievalDealRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='powergate.user.v1.RetrievalDealRecordsRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3451,
)


_RETRIEVALDEALRECORDSRESPONSE = _descriptor.Descriptor(
  name='RetrievalDealRecordsResponse',
  full_name='powergate.user.v1.RetrievalDealRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='records', full_name='powergate.user.v1.RetrievalDealRecordsResponse.records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3453,
  serialized_end=3540,
)


_JOBCOUNTS = _descriptor.Descriptor(
  name='JobCounts',
  full_name='powergate.user.v1.JobCounts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='queued', full_name='powergate.user.v1.JobCounts.queued', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executing', full_name='powergate.user.v1.JobCounts.executing', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_final', full_name='powergate.user.v1.JobCounts.latest_final', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_successful', full_name='powergate.user.v1.JobCounts.latest_successful', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3542,
  serialized_end=3637,
)


_ADDRINFO = _descriptor.Descriptor(
  name='AddrInfo',
  full_name='powergate.user.v1.AddrInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='powergate.user.v1.AddrInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.AddrInfo.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='powergate.user.v1.AddrInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='powergate.user.v1.AddrInfo.balance', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3639,
  serialized_end=3711,
)


_IPFSCONFIG = _descriptor.Descriptor(
  name='IpfsConfig',
  full_name='powergate.user.v1.IpfsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='add_timeout', full_name='powergate.user.v1.IpfsConfig.add_timeout', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3713,
  serialized_end=3746,
)


_HOTCONFIG = _descriptor.Descriptor(
  name='HotConfig',
  full_name='powergate.user.v1.HotConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='powergate.user.v1.HotConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allow_unfreeze', full_name='powergate.user.v1.HotConfig.allow_unfreeze', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unfreeze_max_price', full_name='powergate.user.v1.HotConfig.unfreeze_max_price', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipfs', full_name='powergate.user.v1.HotConfig.ipfs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3748,
  serialized_end=3873,
)


_FILRENEW = _descriptor.Descriptor(
  name='FilRenew',
  full_name='powergate.user.v1.FilRenew',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='powergate.user.v1.FilRenew.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='powergate.user.v1.FilRenew.threshold', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3875,
  serialized_end=3921,
)


_FILCONFIG = _descriptor.Descriptor(
  name='FilConfig',
  full_name='powergate.user.v1.FilConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='replication_factor', full_name='powergate.user.v1.FilConfig.replication_factor', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_min_duration', full_name='powergate.user.v1.FilConfig.deal_min_duration', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='excluded_miners', full_name='powergate.user.v1.FilConfig.excluded_miners', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trusted_miners', full_name='powergate.user.v1.FilConfig.trusted_miners', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country_codes', full_name='powergate.user.v1.FilConfig.country_codes', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='renew', full_name='powergate.user.v1.FilConfig.renew', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.FilConfig.address', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_price', full_name='powergate.user.v1.FilConfig.max_price', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fast_retrieval', full_name='powergate.user.v1.FilConfig.fast_retrieval', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_start_offset', full_name='powergate.user.v1.FilConfig.deal_start_offset', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3924,
  serialized_end=4193,
)


_COLDCONFIG = _descriptor.Descriptor(
  name='ColdConfig',
  full_name='powergate.user.v1.ColdConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='powergate.user.v1.ColdConfig.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filecoin', full_name='powergate.user.v1.ColdConfig.filecoin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4195,
  serialized_end=4272,
)


_STORAGECONFIG = _descriptor.Descriptor(
  name='StorageConfig',
  full_name='powergate.user.v1.StorageConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hot', full_name='powergate.user.v1.StorageConfig.hot', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cold', full_name='powergate.user.v1.StorageConfig.cold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repairable', full_name='powergate.user.v1.StorageConfig.repairable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4274,
  serialized_end=4397,
)


_IPFSHOTINFO = _descriptor.Descriptor(
  name='IpfsHotInfo',
  full_name='powergate.user.v1.IpfsHotInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='powergate.user.v1.IpfsHotInfo.created', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4399,
  serialized_end=4429,
)


_HOTINFO = _descriptor.Descriptor(
  name='HotInfo',
  full_name='powergate.user.v1.HotInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='powergate.user.v1.HotInfo.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='powergate.user.v1.HotInfo.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipfs', full_name='powergate.user.v1.HotInfo.ipfs', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4431,
  serialized_end=4517,
)


_FILSTORAGE = _descriptor.Descriptor(
  name='FilStorage',
  full_name='powergate.user.v1.FilStorage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_cid', full_name='powergate.user.v1.FilStorage.proposal_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='renewed', full_name='powergate.user.v1.FilStorage.renewed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='powergate.user.v1.FilStorage.duration', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_epoch', full_name='powergate.user.v1.FilStorage.activation_epoch', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_epoch', full_name='powergate.user.v1.FilStorage.start_epoch', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='powergate.user.v1.FilStorage.miner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch_price', full_name='powergate.user.v1.FilStorage.epoch_price', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piece_cid', full_name='powergate.user.v1.FilStorage.piece_cid', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4520,
  serialized_end=4691,
)


_FILINFO = _descriptor.Descriptor(
  name='FilInfo',
  full_name='powergate.user.v1.FilInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_cid', full_name='powergate.user.v1.FilInfo.data_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='powergate.user.v1.FilInfo.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposals', full_name='powergate.user.v1.FilInfo.proposals', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4693,
  serialized_end=4784,
)


_COLDINFO = _descriptor.Descriptor(
  name='ColdInfo',
  full_name='powergate.user.v1.ColdInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='powergate.user.v1.ColdInfo.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filecoin', full_name='powergate.user.v1.ColdInfo.filecoin', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4786,
  serialized_end=4859,
)


_STORAGEINFO = _descriptor.Descriptor(
  name='StorageInfo',
  full_name='powergate.user.v1.StorageInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.StorageInfo.job_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.StorageInfo.cid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='powergate.user.v1.StorageInfo.created', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hot', full_name='powergate.user.v1.StorageInfo.hot', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cold', full_name='powergate.user.v1.StorageInfo.cold', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4862,
  serialized_end=5005,
)


_CIDINFO = _descriptor.Descriptor(
  name='CidInfo',
  full_name='powergate.user.v1.CidInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.CidInfo.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_pushed_storage_config', full_name='powergate.user.v1.CidInfo.latest_pushed_storage_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='current_storage_info', full_name='powergate.user.v1.CidInfo.current_storage_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queued_storage_jobs', full_name='powergate.user.v1.CidInfo.queued_storage_jobs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='executing_storage_job', full_name='powergate.user.v1.CidInfo.executing_storage_job', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_final_storage_job', full_name='powergate.user.v1.CidInfo.latest_final_storage_job', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_successful_storage_job', full_name='powergate.user.v1.CidInfo.latest_successful_storage_job', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5008,
  serialized_end=5421,
)


_DEALINFO = _descriptor.Descriptor(
  name='DealInfo',
  full_name='powergate.user.v1.DealInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_cid', full_name='powergate.user.v1.DealInfo.proposal_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_id', full_name='powergate.user.v1.DealInfo.state_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_name', full_name='powergate.user.v1.DealInfo.state_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='powergate.user.v1.DealInfo.miner', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piece_cid', full_name='powergate.user.v1.DealInfo.piece_cid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='powergate.user.v1.DealInfo.size', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_per_epoch', full_name='powergate.user.v1.DealInfo.price_per_epoch', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_epoch', full_name='powergate.user.v1.DealInfo.start_epoch', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='powergate.user.v1.DealInfo.duration', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_id', full_name='powergate.user.v1.DealInfo.deal_id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_epoch', full_name='powergate.user.v1.DealInfo.activation_epoch', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.DealInfo.message', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5424,
  serialized_end=5666,
)


_STORAGEJOB = _descriptor.Descriptor(
  name='StorageJob',
  full_name='powergate.user.v1.StorageJob',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='powergate.user.v1.StorageJob.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='api_id', full_name='powergate.user.v1.StorageJob.api_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.StorageJob.cid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='powergate.user.v1.StorageJob.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_cause', full_name='powergate.user.v1.StorageJob.error_cause', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_info', full_name='powergate.user.v1.StorageJob.deal_info', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_errors', full_name='powergate.user.v1.StorageJob.deal_errors', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='powergate.user.v1.StorageJob.created_at', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5669,
  serialized_end=5908,
)


_DEALERROR = _descriptor.Descriptor(
  name='DealError',
  full_name='powergate.user.v1.DealError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_cid', full_name='powergate.user.v1.DealError.proposal_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='powergate.user.v1.DealError.miner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.DealError.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5910,
  serialized_end=5975,
)


_LOGENTRY = _descriptor.Descriptor(
  name='LogEntry',
  full_name='powergate.user.v1.LogEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cid', full_name='powergate.user.v1.LogEntry.cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='job_id', full_name='powergate.user.v1.LogEntry.job_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='powergate.user.v1.LogEntry.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.LogEntry.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5977,
  serialized_end=6047,
)


_DEALRECORDSCONFIG = _descriptor.Descriptor(
  name='DealRecordsConfig',
  full_name='powergate.user.v1.DealRecordsConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_addrs', full_name='powergate.user.v1.DealRecordsConfig.from_addrs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_cids', full_name='powergate.user.v1.DealRecordsConfig.data_cids', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_pending', full_name='powergate.user.v1.DealRecordsConfig.include_pending', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_final', full_name='powergate.user.v1.DealRecordsConfig.include_final', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ascending', full_name='powergate.user.v1.DealRecordsConfig.ascending', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6049,
  serialized_end=6174,
)


_STORAGEDEALINFO = _descriptor.Descriptor(
  name='StorageDealInfo',
  full_name='powergate.user.v1.StorageDealInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_cid', full_name='powergate.user.v1.StorageDealInfo.proposal_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_id', full_name='powergate.user.v1.StorageDealInfo.state_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state_name', full_name='powergate.user.v1.StorageDealInfo.state_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='powergate.user.v1.StorageDealInfo.miner', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piece_cid', full_name='powergate.user.v1.StorageDealInfo.piece_cid', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='powergate.user.v1.StorageDealInfo.size', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price_per_epoch', full_name='powergate.user.v1.StorageDealInfo.price_per_epoch', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_epoch', full_name='powergate.user.v1.StorageDealInfo.start_epoch', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='duration', full_name='powergate.user.v1.StorageDealInfo.duration', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_id', full_name='powergate.user.v1.StorageDealInfo.deal_id', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='activation_epoch', full_name='powergate.user.v1.StorageDealInfo.activation_epoch', index=10,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='powergate.user.v1.StorageDealInfo.message', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6177,
  serialized_end=6426,
)


_STORAGEDEALRECORD = _descriptor.Descriptor(
  name='StorageDealRecord',
  full_name='powergate.user.v1.StorageDealRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_cid', full_name='powergate.user.v1.StorageDealRecord.root_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.StorageDealRecord.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='powergate.user.v1.StorageDealRecord.time', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending', full_name='powergate.user.v1.StorageDealRecord.pending', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_info', full_name='powergate.user.v1.StorageDealRecord.deal_info', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6429,
  serialized_end=6569,
)


_RETRIEVALDEALINFO = _descriptor.Descriptor(
  name='RetrievalDealInfo',
  full_name='powergate.user.v1.RetrievalDealInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='root_cid', full_name='powergate.user.v1.RetrievalDealInfo.root_cid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='powergate.user.v1.RetrievalDealInfo.size', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_price', full_name='powergate.user.v1.RetrievalDealInfo.min_price', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_interval', full_name='powergate.user.v1.RetrievalDealInfo.payment_interval', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment_interval_increase', full_name='powergate.user.v1.RetrievalDealInfo.payment_interval_increase', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner', full_name='powergate.user.v1.RetrievalDealInfo.miner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='miner_peer_id', full_name='powergate.user.v1.RetrievalDealInfo.miner_peer_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6572,
  serialized_end=6741,
)


_RETRIEVALDEALRECORD = _descriptor.Descriptor(
  name='RetrievalDealRecord',
  full_name='powergate.user.v1.RetrievalDealRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='powergate.user.v1.RetrievalDealRecord.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='powergate.user.v1.RetrievalDealRecord.time', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deal_info', full_name='powergate.user.v1.RetrievalDealRecord.deal_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6743,
  serialized_end=6852,
)

_DEFAULTSTORAGECONFIGRESPONSE.fields_by_name['default_storage_config'].message_type = _STORAGECONFIG
_SETDEFAULTSTORAGECONFIGREQUEST.fields_by_name['config'].message_type = _STORAGECONFIG
_APPLYSTORAGECONFIGREQUEST.fields_by_name['config'].message_type = _STORAGECONFIG
_WATCHLOGSRESPONSE.fields_by_name['log_entry'].message_type = _LOGENTRY
_CIDINFORESPONSE.fields_by_name['cid_infos'].message_type = _CIDINFO
_ADDRESSESRESPONSE.fields_by_name['addresses'].message_type = _ADDRINFO
_STORAGEJOBRESPONSE.fields_by_name['storage_job'].message_type = _STORAGEJOB
_STORAGECONFIGFORJOBRESPONSE.fields_by_name['storage_config'].message_type = _STORAGECONFIG
_QUEUEDSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = _STORAGEJOB
_EXECUTINGSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = _STORAGEJOB
_LATESTFINALSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = _STORAGEJOB
_LATESTSUCCESSFULSTORAGEJOBSRESPONSE.fields_by_name['storage_jobs'].message_type = _STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['job_counts'].message_type = _JOBCOUNTS
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['queued_storage_jobs'].message_type = _STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['executing_storage_jobs'].message_type = _STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['latest_final_storage_jobs'].message_type = _STORAGEJOB
_STORAGEJOBSSUMMARYRESPONSE.fields_by_name['latest_successful_storage_jobs'].message_type = _STORAGEJOB
_WATCHSTORAGEJOBSRESPONSE.fields_by_name['storage_job'].message_type = _STORAGEJOB
_STORAGEDEALRECORDSREQUEST.fields_by_name['config'].message_type = _DEALRECORDSCONFIG
_STORAGEDEALRECORDSRESPONSE.fields_by_name['records'].message_type = _STORAGEDEALRECORD
_RETRIEVALDEALRECORDSREQUEST.fields_by_name['config'].message_type = _DEALRECORDSCONFIG
_RETRIEVALDEALRECORDSRESPONSE.fields_by_name['records'].message_type = _RETRIEVALDEALRECORD
_HOTCONFIG.fields_by_name['ipfs'].message_type = _IPFSCONFIG
_FILCONFIG.fields_by_name['renew'].message_type = _FILRENEW
_COLDCONFIG.fields_by_name['filecoin'].message_type = _FILCONFIG
_STORAGECONFIG.fields_by_name['hot'].message_type = _HOTCONFIG
_STORAGECONFIG.fields_by_name['cold'].message_type = _COLDCONFIG
_HOTINFO.fields_by_name['ipfs'].message_type = _IPFSHOTINFO
_FILINFO.fields_by_name['proposals'].message_type = _FILSTORAGE
_COLDINFO.fields_by_name['filecoin'].message_type = _FILINFO
_STORAGEINFO.fields_by_name['hot'].message_type = _HOTINFO
_STORAGEINFO.fields_by_name['cold'].message_type = _COLDINFO
_CIDINFO.fields_by_name['latest_pushed_storage_config'].message_type = _STORAGECONFIG
_CIDINFO.fields_by_name['current_storage_info'].message_type = _STORAGEINFO
_CIDINFO.fields_by_name['queued_storage_jobs'].message_type = _STORAGEJOB
_CIDINFO.fields_by_name['executing_storage_job'].message_type = _STORAGEJOB
_CIDINFO.fields_by_name['latest_final_storage_job'].message_type = _STORAGEJOB
_CIDINFO.fields_by_name['latest_successful_storage_job'].message_type = _STORAGEJOB
_STORAGEJOB.fields_by_name['status'].enum_type = _JOBSTATUS
_STORAGEJOB.fields_by_name['deal_info'].message_type = _DEALINFO
_STORAGEJOB.fields_by_name['deal_errors'].message_type = _DEALERROR
_STORAGEDEALRECORD.fields_by_name['deal_info'].message_type = _STORAGEDEALINFO
_RETRIEVALDEALRECORD.fields_by_name['deal_info'].message_type = _RETRIEVALDEALINFO
DESCRIPTOR.message_types_by_name['BuildInfoRequest'] = _BUILDINFOREQUEST
DESCRIPTOR.message_types_by_name['BuildInfoResponse'] = _BUILDINFORESPONSE
DESCRIPTOR.message_types_by_name['UserIdentifierRequest'] = _USERIDENTIFIERREQUEST
DESCRIPTOR.message_types_by_name['UserIdentifierResponse'] = _USERIDENTIFIERRESPONSE
DESCRIPTOR.message_types_by_name['DefaultStorageConfigRequest'] = _DEFAULTSTORAGECONFIGREQUEST
DESCRIPTOR.message_types_by_name['DefaultStorageConfigResponse'] = _DEFAULTSTORAGECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['SetDefaultStorageConfigRequest'] = _SETDEFAULTSTORAGECONFIGREQUEST
DESCRIPTOR.message_types_by_name['SetDefaultStorageConfigResponse'] = _SETDEFAULTSTORAGECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['StageRequest'] = _STAGEREQUEST
DESCRIPTOR.message_types_by_name['StageResponse'] = _STAGERESPONSE
DESCRIPTOR.message_types_by_name['StageCidRequest'] = _STAGECIDREQUEST
DESCRIPTOR.message_types_by_name['StageCidResponse'] = _STAGECIDRESPONSE
DESCRIPTOR.message_types_by_name['ApplyStorageConfigRequest'] = _APPLYSTORAGECONFIGREQUEST
DESCRIPTOR.message_types_by_name['ApplyStorageConfigResponse'] = _APPLYSTORAGECONFIGRESPONSE
DESCRIPTOR.message_types_by_name['ReplaceDataRequest'] = _REPLACEDATAREQUEST
DESCRIPTOR.message_types_by_name['ReplaceDataResponse'] = _REPLACEDATARESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['RemoveRequest'] = _REMOVEREQUEST
DESCRIPTOR.message_types_by_name['RemoveResponse'] = _REMOVERESPONSE
DESCRIPTOR.message_types_by_name['WatchLogsRequest'] = _WATCHLOGSREQUEST
DESCRIPTOR.message_types_by_name['WatchLogsResponse'] = _WATCHLOGSRESPONSE
DESCRIPTOR.message_types_by_name['CidInfoRequest'] = _CIDINFOREQUEST
DESCRIPTOR.message_types_by_name['CidInfoResponse'] = _CIDINFORESPONSE
DESCRIPTOR.message_types_by_name['BalanceRequest'] = _BALANCEREQUEST
DESCRIPTOR.message_types_by_name['BalanceResponse'] = _BALANCERESPONSE
DESCRIPTOR.message_types_by_name['NewAddressRequest'] = _NEWADDRESSREQUEST
DESCRIPTOR.message_types_by_name['NewAddressResponse'] = _NEWADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['AddressesRequest'] = _ADDRESSESREQUEST
DESCRIPTOR.message_types_by_name['AddressesResponse'] = _ADDRESSESRESPONSE
DESCRIPTOR.message_types_by_name['SendFilRequest'] = _SENDFILREQUEST
DESCRIPTOR.message_types_by_name['SendFilResponse'] = _SENDFILRESPONSE
DESCRIPTOR.message_types_by_name['SignMessageRequest'] = _SIGNMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['SignMessageResponse'] = _SIGNMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['VerifyMessageRequest'] = _VERIFYMESSAGEREQUEST
DESCRIPTOR.message_types_by_name['VerifyMessageResponse'] = _VERIFYMESSAGERESPONSE
DESCRIPTOR.message_types_by_name['CancelStorageJobRequest'] = _CANCELSTORAGEJOBREQUEST
DESCRIPTOR.message_types_by_name['CancelStorageJobResponse'] = _CANCELSTORAGEJOBRESPONSE
DESCRIPTOR.message_types_by_name['StorageJobRequest'] = _STORAGEJOBREQUEST
DESCRIPTOR.message_types_by_name['StorageJobResponse'] = _STORAGEJOBRESPONSE
DESCRIPTOR.message_types_by_name['StorageConfigForJobRequest'] = _STORAGECONFIGFORJOBREQUEST
DESCRIPTOR.message_types_by_name['StorageConfigForJobResponse'] = _STORAGECONFIGFORJOBRESPONSE
DESCRIPTOR.message_types_by_name['QueuedStorageJobsRequest'] = _QUEUEDSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['QueuedStorageJobsResponse'] = _QUEUEDSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['ExecutingStorageJobsRequest'] = _EXECUTINGSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['ExecutingStorageJobsResponse'] = _EXECUTINGSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['LatestFinalStorageJobsRequest'] = _LATESTFINALSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['LatestFinalStorageJobsResponse'] = _LATESTFINALSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['LatestSuccessfulStorageJobsRequest'] = _LATESTSUCCESSFULSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['LatestSuccessfulStorageJobsResponse'] = _LATESTSUCCESSFULSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['StorageJobsSummaryRequest'] = _STORAGEJOBSSUMMARYREQUEST
DESCRIPTOR.message_types_by_name['StorageJobsSummaryResponse'] = _STORAGEJOBSSUMMARYRESPONSE
DESCRIPTOR.message_types_by_name['WatchStorageJobsRequest'] = _WATCHSTORAGEJOBSREQUEST
DESCRIPTOR.message_types_by_name['WatchStorageJobsResponse'] = _WATCHSTORAGEJOBSRESPONSE
DESCRIPTOR.message_types_by_name['StorageDealRecordsRequest'] = _STORAGEDEALRECORDSREQUEST
DESCRIPTOR.message_types_by_name['StorageDealRecordsResponse'] = _STORAGEDEALRECORDSRESPONSE
DESCRIPTOR.message_types_by_name['RetrievalDealRecordsRequest'] = _RETRIEVALDEALRECORDSREQUEST
DESCRIPTOR.message_types_by_name['RetrievalDealRecordsResponse'] = _RETRIEVALDEALRECORDSRESPONSE
DESCRIPTOR.message_types_by_name['JobCounts'] = _JOBCOUNTS
DESCRIPTOR.message_types_by_name['AddrInfo'] = _ADDRINFO
DESCRIPTOR.message_types_by_name['IpfsConfig'] = _IPFSCONFIG
DESCRIPTOR.message_types_by_name['HotConfig'] = _HOTCONFIG
DESCRIPTOR.message_types_by_name['FilRenew'] = _FILRENEW
DESCRIPTOR.message_types_by_name['FilConfig'] = _FILCONFIG
DESCRIPTOR.message_types_by_name['ColdConfig'] = _COLDCONFIG
DESCRIPTOR.message_types_by_name['StorageConfig'] = _STORAGECONFIG
DESCRIPTOR.message_types_by_name['IpfsHotInfo'] = _IPFSHOTINFO
DESCRIPTOR.message_types_by_name['HotInfo'] = _HOTINFO
DESCRIPTOR.message_types_by_name['FilStorage'] = _FILSTORAGE
DESCRIPTOR.message_types_by_name['FilInfo'] = _FILINFO
DESCRIPTOR.message_types_by_name['ColdInfo'] = _COLDINFO
DESCRIPTOR.message_types_by_name['StorageInfo'] = _STORAGEINFO
DESCRIPTOR.message_types_by_name['CidInfo'] = _CIDINFO
DESCRIPTOR.message_types_by_name['DealInfo'] = _DEALINFO
DESCRIPTOR.message_types_by_name['StorageJob'] = _STORAGEJOB
DESCRIPTOR.message_types_by_name['DealError'] = _DEALERROR
DESCRIPTOR.message_types_by_name['LogEntry'] = _LOGENTRY
DESCRIPTOR.message_types_by_name['DealRecordsConfig'] = _DEALRECORDSCONFIG
DESCRIPTOR.message_types_by_name['StorageDealInfo'] = _STORAGEDEALINFO
DESCRIPTOR.message_types_by_name['StorageDealRecord'] = _STORAGEDEALRECORD
DESCRIPTOR.message_types_by_name['RetrievalDealInfo'] = _RETRIEVALDEALINFO
DESCRIPTOR.message_types_by_name['RetrievalDealRecord'] = _RETRIEVALDEALRECORD
DESCRIPTOR.enum_types_by_name['JobStatus'] = _JOBSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BuildInfoRequest = _reflection.GeneratedProtocolMessageType('BuildInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINFOREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.BuildInfoRequest)
  })
_sym_db.RegisterMessage(BuildInfoRequest)

BuildInfoResponse = _reflection.GeneratedProtocolMessageType('BuildInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _BUILDINFORESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.BuildInfoResponse)
  })
_sym_db.RegisterMessage(BuildInfoResponse)

UserIdentifierRequest = _reflection.GeneratedProtocolMessageType('UserIdentifierRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERIDENTIFIERREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.UserIdentifierRequest)
  })
_sym_db.RegisterMessage(UserIdentifierRequest)

UserIdentifierResponse = _reflection.GeneratedProtocolMessageType('UserIdentifierResponse', (_message.Message,), {
  'DESCRIPTOR' : _USERIDENTIFIERRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.UserIdentifierResponse)
  })
_sym_db.RegisterMessage(UserIdentifierResponse)

DefaultStorageConfigRequest = _reflection.GeneratedProtocolMessageType('DefaultStorageConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTSTORAGECONFIGREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.DefaultStorageConfigRequest)
  })
_sym_db.RegisterMessage(DefaultStorageConfigRequest)

DefaultStorageConfigResponse = _reflection.GeneratedProtocolMessageType('DefaultStorageConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEFAULTSTORAGECONFIGRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.DefaultStorageConfigResponse)
  })
_sym_db.RegisterMessage(DefaultStorageConfigResponse)

SetDefaultStorageConfigRequest = _reflection.GeneratedProtocolMessageType('SetDefaultStorageConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTSTORAGECONFIGREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SetDefaultStorageConfigRequest)
  })
_sym_db.RegisterMessage(SetDefaultStorageConfigRequest)

SetDefaultStorageConfigResponse = _reflection.GeneratedProtocolMessageType('SetDefaultStorageConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDEFAULTSTORAGECONFIGRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SetDefaultStorageConfigResponse)
  })
_sym_db.RegisterMessage(SetDefaultStorageConfigResponse)

StageRequest = _reflection.GeneratedProtocolMessageType('StageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STAGEREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StageRequest)
  })
_sym_db.RegisterMessage(StageRequest)

StageResponse = _reflection.GeneratedProtocolMessageType('StageResponse', (_message.Message,), {
  'DESCRIPTOR' : _STAGERESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StageResponse)
  })
_sym_db.RegisterMessage(StageResponse)

StageCidRequest = _reflection.GeneratedProtocolMessageType('StageCidRequest', (_message.Message,), {
  'DESCRIPTOR' : _STAGECIDREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StageCidRequest)
  })
_sym_db.RegisterMessage(StageCidRequest)

StageCidResponse = _reflection.GeneratedProtocolMessageType('StageCidResponse', (_message.Message,), {
  'DESCRIPTOR' : _STAGECIDRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StageCidResponse)
  })
_sym_db.RegisterMessage(StageCidResponse)

ApplyStorageConfigRequest = _reflection.GeneratedProtocolMessageType('ApplyStorageConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPLYSTORAGECONFIGREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ApplyStorageConfigRequest)
  })
_sym_db.RegisterMessage(ApplyStorageConfigRequest)

ApplyStorageConfigResponse = _reflection.GeneratedProtocolMessageType('ApplyStorageConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPLYSTORAGECONFIGRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ApplyStorageConfigResponse)
  })
_sym_db.RegisterMessage(ApplyStorageConfigResponse)

ReplaceDataRequest = _reflection.GeneratedProtocolMessageType('ReplaceDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPLACEDATAREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ReplaceDataRequest)
  })
_sym_db.RegisterMessage(ReplaceDataRequest)

ReplaceDataResponse = _reflection.GeneratedProtocolMessageType('ReplaceDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _REPLACEDATARESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ReplaceDataResponse)
  })
_sym_db.RegisterMessage(ReplaceDataResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.GetRequest)
  })
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.GetResponse)
  })
_sym_db.RegisterMessage(GetResponse)

RemoveRequest = _reflection.GeneratedProtocolMessageType('RemoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RemoveRequest)
  })
_sym_db.RegisterMessage(RemoveRequest)

RemoveResponse = _reflection.GeneratedProtocolMessageType('RemoveResponse', (_message.Message,), {
  'DESCRIPTOR' : _REMOVERESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RemoveResponse)
  })
_sym_db.RegisterMessage(RemoveResponse)

WatchLogsRequest = _reflection.GeneratedProtocolMessageType('WatchLogsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHLOGSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.WatchLogsRequest)
  })
_sym_db.RegisterMessage(WatchLogsRequest)

WatchLogsResponse = _reflection.GeneratedProtocolMessageType('WatchLogsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHLOGSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.WatchLogsResponse)
  })
_sym_db.RegisterMessage(WatchLogsResponse)

CidInfoRequest = _reflection.GeneratedProtocolMessageType('CidInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _CIDINFOREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.CidInfoRequest)
  })
_sym_db.RegisterMessage(CidInfoRequest)

CidInfoResponse = _reflection.GeneratedProtocolMessageType('CidInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CIDINFORESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.CidInfoResponse)
  })
_sym_db.RegisterMessage(CidInfoResponse)

BalanceRequest = _reflection.GeneratedProtocolMessageType('BalanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.BalanceRequest)
  })
_sym_db.RegisterMessage(BalanceRequest)

BalanceResponse = _reflection.GeneratedProtocolMessageType('BalanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _BALANCERESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.BalanceResponse)
  })
_sym_db.RegisterMessage(BalanceResponse)

NewAddressRequest = _reflection.GeneratedProtocolMessageType('NewAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.NewAddressRequest)
  })
_sym_db.RegisterMessage(NewAddressRequest)

NewAddressResponse = _reflection.GeneratedProtocolMessageType('NewAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWADDRESSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.NewAddressResponse)
  })
_sym_db.RegisterMessage(NewAddressResponse)

AddressesRequest = _reflection.GeneratedProtocolMessageType('AddressesRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.AddressesRequest)
  })
_sym_db.RegisterMessage(AddressesRequest)

AddressesResponse = _reflection.GeneratedProtocolMessageType('AddressesResponse', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESSESRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.AddressesResponse)
  })
_sym_db.RegisterMessage(AddressesResponse)

SendFilRequest = _reflection.GeneratedProtocolMessageType('SendFilRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SendFilRequest)
  })
_sym_db.RegisterMessage(SendFilRequest)

SendFilResponse = _reflection.GeneratedProtocolMessageType('SendFilResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDFILRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SendFilResponse)
  })
_sym_db.RegisterMessage(SendFilResponse)

SignMessageRequest = _reflection.GeneratedProtocolMessageType('SignMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _SIGNMESSAGEREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SignMessageRequest)
  })
_sym_db.RegisterMessage(SignMessageRequest)

SignMessageResponse = _reflection.GeneratedProtocolMessageType('SignMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _SIGNMESSAGERESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.SignMessageResponse)
  })
_sym_db.RegisterMessage(SignMessageResponse)

VerifyMessageRequest = _reflection.GeneratedProtocolMessageType('VerifyMessageRequest', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYMESSAGEREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.VerifyMessageRequest)
  })
_sym_db.RegisterMessage(VerifyMessageRequest)

VerifyMessageResponse = _reflection.GeneratedProtocolMessageType('VerifyMessageResponse', (_message.Message,), {
  'DESCRIPTOR' : _VERIFYMESSAGERESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.VerifyMessageResponse)
  })
_sym_db.RegisterMessage(VerifyMessageResponse)

CancelStorageJobRequest = _reflection.GeneratedProtocolMessageType('CancelStorageJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _CANCELSTORAGEJOBREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.CancelStorageJobRequest)
  })
_sym_db.RegisterMessage(CancelStorageJobRequest)

CancelStorageJobResponse = _reflection.GeneratedProtocolMessageType('CancelStorageJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _CANCELSTORAGEJOBRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.CancelStorageJobResponse)
  })
_sym_db.RegisterMessage(CancelStorageJobResponse)

StorageJobRequest = _reflection.GeneratedProtocolMessageType('StorageJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageJobRequest)
  })
_sym_db.RegisterMessage(StorageJobRequest)

StorageJobResponse = _reflection.GeneratedProtocolMessageType('StorageJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageJobResponse)
  })
_sym_db.RegisterMessage(StorageJobResponse)

StorageConfigForJobRequest = _reflection.GeneratedProtocolMessageType('StorageConfigForJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGECONFIGFORJOBREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageConfigForJobRequest)
  })
_sym_db.RegisterMessage(StorageConfigForJobRequest)

StorageConfigForJobResponse = _reflection.GeneratedProtocolMessageType('StorageConfigForJobResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGECONFIGFORJOBRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageConfigForJobResponse)
  })
_sym_db.RegisterMessage(StorageConfigForJobResponse)

QueuedStorageJobsRequest = _reflection.GeneratedProtocolMessageType('QueuedStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.QueuedStorageJobsRequest)
  })
_sym_db.RegisterMessage(QueuedStorageJobsRequest)

QueuedStorageJobsResponse = _reflection.GeneratedProtocolMessageType('QueuedStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUEUEDSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.QueuedStorageJobsResponse)
  })
_sym_db.RegisterMessage(QueuedStorageJobsResponse)

ExecutingStorageJobsRequest = _reflection.GeneratedProtocolMessageType('ExecutingStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTINGSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ExecutingStorageJobsRequest)
  })
_sym_db.RegisterMessage(ExecutingStorageJobsRequest)

ExecutingStorageJobsResponse = _reflection.GeneratedProtocolMessageType('ExecutingStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTINGSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ExecutingStorageJobsResponse)
  })
_sym_db.RegisterMessage(ExecutingStorageJobsResponse)

LatestFinalStorageJobsRequest = _reflection.GeneratedProtocolMessageType('LatestFinalStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LATESTFINALSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.LatestFinalStorageJobsRequest)
  })
_sym_db.RegisterMessage(LatestFinalStorageJobsRequest)

LatestFinalStorageJobsResponse = _reflection.GeneratedProtocolMessageType('LatestFinalStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LATESTFINALSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.LatestFinalStorageJobsResponse)
  })
_sym_db.RegisterMessage(LatestFinalStorageJobsResponse)

LatestSuccessfulStorageJobsRequest = _reflection.GeneratedProtocolMessageType('LatestSuccessfulStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LATESTSUCCESSFULSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.LatestSuccessfulStorageJobsRequest)
  })
_sym_db.RegisterMessage(LatestSuccessfulStorageJobsRequest)

LatestSuccessfulStorageJobsResponse = _reflection.GeneratedProtocolMessageType('LatestSuccessfulStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LATESTSUCCESSFULSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.LatestSuccessfulStorageJobsResponse)
  })
_sym_db.RegisterMessage(LatestSuccessfulStorageJobsResponse)

StorageJobsSummaryRequest = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageJobsSummaryRequest)
  })
_sym_db.RegisterMessage(StorageJobsSummaryRequest)

StorageJobsSummaryResponse = _reflection.GeneratedProtocolMessageType('StorageJobsSummaryResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOBSSUMMARYRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageJobsSummaryResponse)
  })
_sym_db.RegisterMessage(StorageJobsSummaryResponse)

WatchStorageJobsRequest = _reflection.GeneratedProtocolMessageType('WatchStorageJobsRequest', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSTORAGEJOBSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.WatchStorageJobsRequest)
  })
_sym_db.RegisterMessage(WatchStorageJobsRequest)

WatchStorageJobsResponse = _reflection.GeneratedProtocolMessageType('WatchStorageJobsResponse', (_message.Message,), {
  'DESCRIPTOR' : _WATCHSTORAGEJOBSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.WatchStorageJobsResponse)
  })
_sym_db.RegisterMessage(WatchStorageJobsResponse)

StorageDealRecordsRequest = _reflection.GeneratedProtocolMessageType('StorageDealRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEDEALRECORDSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageDealRecordsRequest)
  })
_sym_db.RegisterMessage(StorageDealRecordsRequest)

StorageDealRecordsResponse = _reflection.GeneratedProtocolMessageType('StorageDealRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEDEALRECORDSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageDealRecordsResponse)
  })
_sym_db.RegisterMessage(StorageDealRecordsResponse)

RetrievalDealRecordsRequest = _reflection.GeneratedProtocolMessageType('RetrievalDealRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVALDEALRECORDSREQUEST,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RetrievalDealRecordsRequest)
  })
_sym_db.RegisterMessage(RetrievalDealRecordsRequest)

RetrievalDealRecordsResponse = _reflection.GeneratedProtocolMessageType('RetrievalDealRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVALDEALRECORDSRESPONSE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RetrievalDealRecordsResponse)
  })
_sym_db.RegisterMessage(RetrievalDealRecordsResponse)

JobCounts = _reflection.GeneratedProtocolMessageType('JobCounts', (_message.Message,), {
  'DESCRIPTOR' : _JOBCOUNTS,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.JobCounts)
  })
_sym_db.RegisterMessage(JobCounts)

AddrInfo = _reflection.GeneratedProtocolMessageType('AddrInfo', (_message.Message,), {
  'DESCRIPTOR' : _ADDRINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.AddrInfo)
  })
_sym_db.RegisterMessage(AddrInfo)

IpfsConfig = _reflection.GeneratedProtocolMessageType('IpfsConfig', (_message.Message,), {
  'DESCRIPTOR' : _IPFSCONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.IpfsConfig)
  })
_sym_db.RegisterMessage(IpfsConfig)

HotConfig = _reflection.GeneratedProtocolMessageType('HotConfig', (_message.Message,), {
  'DESCRIPTOR' : _HOTCONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.HotConfig)
  })
_sym_db.RegisterMessage(HotConfig)

FilRenew = _reflection.GeneratedProtocolMessageType('FilRenew', (_message.Message,), {
  'DESCRIPTOR' : _FILRENEW,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.FilRenew)
  })
_sym_db.RegisterMessage(FilRenew)

FilConfig = _reflection.GeneratedProtocolMessageType('FilConfig', (_message.Message,), {
  'DESCRIPTOR' : _FILCONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.FilConfig)
  })
_sym_db.RegisterMessage(FilConfig)

ColdConfig = _reflection.GeneratedProtocolMessageType('ColdConfig', (_message.Message,), {
  'DESCRIPTOR' : _COLDCONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ColdConfig)
  })
_sym_db.RegisterMessage(ColdConfig)

StorageConfig = _reflection.GeneratedProtocolMessageType('StorageConfig', (_message.Message,), {
  'DESCRIPTOR' : _STORAGECONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageConfig)
  })
_sym_db.RegisterMessage(StorageConfig)

IpfsHotInfo = _reflection.GeneratedProtocolMessageType('IpfsHotInfo', (_message.Message,), {
  'DESCRIPTOR' : _IPFSHOTINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.IpfsHotInfo)
  })
_sym_db.RegisterMessage(IpfsHotInfo)

HotInfo = _reflection.GeneratedProtocolMessageType('HotInfo', (_message.Message,), {
  'DESCRIPTOR' : _HOTINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.HotInfo)
  })
_sym_db.RegisterMessage(HotInfo)

FilStorage = _reflection.GeneratedProtocolMessageType('FilStorage', (_message.Message,), {
  'DESCRIPTOR' : _FILSTORAGE,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.FilStorage)
  })
_sym_db.RegisterMessage(FilStorage)

FilInfo = _reflection.GeneratedProtocolMessageType('FilInfo', (_message.Message,), {
  'DESCRIPTOR' : _FILINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.FilInfo)
  })
_sym_db.RegisterMessage(FilInfo)

ColdInfo = _reflection.GeneratedProtocolMessageType('ColdInfo', (_message.Message,), {
  'DESCRIPTOR' : _COLDINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.ColdInfo)
  })
_sym_db.RegisterMessage(ColdInfo)

StorageInfo = _reflection.GeneratedProtocolMessageType('StorageInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageInfo)
  })
_sym_db.RegisterMessage(StorageInfo)

CidInfo = _reflection.GeneratedProtocolMessageType('CidInfo', (_message.Message,), {
  'DESCRIPTOR' : _CIDINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.CidInfo)
  })
_sym_db.RegisterMessage(CidInfo)

DealInfo = _reflection.GeneratedProtocolMessageType('DealInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEALINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.DealInfo)
  })
_sym_db.RegisterMessage(DealInfo)

StorageJob = _reflection.GeneratedProtocolMessageType('StorageJob', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEJOB,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageJob)
  })
_sym_db.RegisterMessage(StorageJob)

DealError = _reflection.GeneratedProtocolMessageType('DealError', (_message.Message,), {
  'DESCRIPTOR' : _DEALERROR,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.DealError)
  })
_sym_db.RegisterMessage(DealError)

LogEntry = _reflection.GeneratedProtocolMessageType('LogEntry', (_message.Message,), {
  'DESCRIPTOR' : _LOGENTRY,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.LogEntry)
  })
_sym_db.RegisterMessage(LogEntry)

DealRecordsConfig = _reflection.GeneratedProtocolMessageType('DealRecordsConfig', (_message.Message,), {
  'DESCRIPTOR' : _DEALRECORDSCONFIG,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.DealRecordsConfig)
  })
_sym_db.RegisterMessage(DealRecordsConfig)

StorageDealInfo = _reflection.GeneratedProtocolMessageType('StorageDealInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEDEALINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageDealInfo)
  })
_sym_db.RegisterMessage(StorageDealInfo)

StorageDealRecord = _reflection.GeneratedProtocolMessageType('StorageDealRecord', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEDEALRECORD,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.StorageDealRecord)
  })
_sym_db.RegisterMessage(StorageDealRecord)

RetrievalDealInfo = _reflection.GeneratedProtocolMessageType('RetrievalDealInfo', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVALDEALINFO,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RetrievalDealInfo)
  })
_sym_db.RegisterMessage(RetrievalDealInfo)

RetrievalDealRecord = _reflection.GeneratedProtocolMessageType('RetrievalDealRecord', (_message.Message,), {
  'DESCRIPTOR' : _RETRIEVALDEALRECORD,
  '__module__' : 'powergate.user.v1.user_pb2'
  # @@protoc_insertion_point(class_scope:powergate.user.v1.RetrievalDealRecord)
  })
_sym_db.RegisterMessage(RetrievalDealRecord)


DESCRIPTOR._options = None

_USERSERVICE = _descriptor.ServiceDescriptor(
  name='UserService',
  full_name='powergate.user.v1.UserService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=7018,
  serialized_end=10047,
  methods=[
  _descriptor.MethodDescriptor(
    name='BuildInfo',
    full_name='powergate.user.v1.UserService.BuildInfo',
    index=0,
    containing_service=None,
    input_type=_BUILDINFOREQUEST,
    output_type=_BUILDINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UserIdentifier',
    full_name='powergate.user.v1.UserService.UserIdentifier',
    index=1,
    containing_service=None,
    input_type=_USERIDENTIFIERREQUEST,
    output_type=_USERIDENTIFIERRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DefaultStorageConfig',
    full_name='powergate.user.v1.UserService.DefaultStorageConfig',
    index=2,
    containing_service=None,
    input_type=_DEFAULTSTORAGECONFIGREQUEST,
    output_type=_DEFAULTSTORAGECONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDefaultStorageConfig',
    full_name='powergate.user.v1.UserService.SetDefaultStorageConfig',
    index=3,
    containing_service=None,
    input_type=_SETDEFAULTSTORAGECONFIGREQUEST,
    output_type=_SETDEFAULTSTORAGECONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ApplyStorageConfig',
    full_name='powergate.user.v1.UserService.ApplyStorageConfig',
    index=4,
    containing_service=None,
    input_type=_APPLYSTORAGECONFIGREQUEST,
    output_type=_APPLYSTORAGECONFIGRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Remove',
    full_name='powergate.user.v1.UserService.Remove',
    index=5,
    containing_service=None,
    input_type=_REMOVEREQUEST,
    output_type=_REMOVERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stage',
    full_name='powergate.user.v1.UserService.Stage',
    index=6,
    containing_service=None,
    input_type=_STAGEREQUEST,
    output_type=_STAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StageCid',
    full_name='powergate.user.v1.UserService.StageCid',
    index=7,
    containing_service=None,
    input_type=_STAGECIDREQUEST,
    output_type=_STAGECIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReplaceData',
    full_name='powergate.user.v1.UserService.ReplaceData',
    index=8,
    containing_service=None,
    input_type=_REPLACEDATAREQUEST,
    output_type=_REPLACEDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='powergate.user.v1.UserService.Get',
    index=9,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchLogs',
    full_name='powergate.user.v1.UserService.WatchLogs',
    index=10,
    containing_service=None,
    input_type=_WATCHLOGSREQUEST,
    output_type=_WATCHLOGSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CidInfo',
    full_name='powergate.user.v1.UserService.CidInfo',
    index=11,
    containing_service=None,
    input_type=_CIDINFOREQUEST,
    output_type=_CIDINFORESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Balance',
    full_name='powergate.user.v1.UserService.Balance',
    index=12,
    containing_service=None,
    input_type=_BALANCEREQUEST,
    output_type=_BALANCERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NewAddress',
    full_name='powergate.user.v1.UserService.NewAddress',
    index=13,
    containing_service=None,
    input_type=_NEWADDRESSREQUEST,
    output_type=_NEWADDRESSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Addresses',
    full_name='powergate.user.v1.UserService.Addresses',
    index=14,
    containing_service=None,
    input_type=_ADDRESSESREQUEST,
    output_type=_ADDRESSESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendFil',
    full_name='powergate.user.v1.UserService.SendFil',
    index=15,
    containing_service=None,
    input_type=_SENDFILREQUEST,
    output_type=_SENDFILRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SignMessage',
    full_name='powergate.user.v1.UserService.SignMessage',
    index=16,
    containing_service=None,
    input_type=_SIGNMESSAGEREQUEST,
    output_type=_SIGNMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='VerifyMessage',
    full_name='powergate.user.v1.UserService.VerifyMessage',
    index=17,
    containing_service=None,
    input_type=_VERIFYMESSAGEREQUEST,
    output_type=_VERIFYMESSAGERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageJob',
    full_name='powergate.user.v1.UserService.StorageJob',
    index=18,
    containing_service=None,
    input_type=_STORAGEJOBREQUEST,
    output_type=_STORAGEJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageConfigForJob',
    full_name='powergate.user.v1.UserService.StorageConfigForJob',
    index=19,
    containing_service=None,
    input_type=_STORAGECONFIGFORJOBREQUEST,
    output_type=_STORAGECONFIGFORJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueuedStorageJobs',
    full_name='powergate.user.v1.UserService.QueuedStorageJobs',
    index=20,
    containing_service=None,
    input_type=_QUEUEDSTORAGEJOBSREQUEST,
    output_type=_QUEUEDSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExecutingStorageJobs',
    full_name='powergate.user.v1.UserService.ExecutingStorageJobs',
    index=21,
    containing_service=None,
    input_type=_EXECUTINGSTORAGEJOBSREQUEST,
    output_type=_EXECUTINGSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestFinalStorageJobs',
    full_name='powergate.user.v1.UserService.LatestFinalStorageJobs',
    index=22,
    containing_service=None,
    input_type=_LATESTFINALSTORAGEJOBSREQUEST,
    output_type=_LATESTFINALSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LatestSuccessfulStorageJobs',
    full_name='powergate.user.v1.UserService.LatestSuccessfulStorageJobs',
    index=23,
    containing_service=None,
    input_type=_LATESTSUCCESSFULSTORAGEJOBSREQUEST,
    output_type=_LATESTSUCCESSFULSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageJobsSummary',
    full_name='powergate.user.v1.UserService.StorageJobsSummary',
    index=24,
    containing_service=None,
    input_type=_STORAGEJOBSSUMMARYREQUEST,
    output_type=_STORAGEJOBSSUMMARYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='WatchStorageJobs',
    full_name='powergate.user.v1.UserService.WatchStorageJobs',
    index=25,
    containing_service=None,
    input_type=_WATCHSTORAGEJOBSREQUEST,
    output_type=_WATCHSTORAGEJOBSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CancelStorageJob',
    full_name='powergate.user.v1.UserService.CancelStorageJob',
    index=26,
    containing_service=None,
    input_type=_CANCELSTORAGEJOBREQUEST,
    output_type=_CANCELSTORAGEJOBRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='StorageDealRecords',
    full_name='powergate.user.v1.UserService.StorageDealRecords',
    index=27,
    containing_service=None,
    input_type=_STORAGEDEALRECORDSREQUEST,
    output_type=_STORAGEDEALRECORDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RetrievalDealRecords',
    full_name='powergate.user.v1.UserService.RetrievalDealRecords',
    index=28,
    containing_service=None,
    input_type=_RETRIEVALDEALRECORDSREQUEST,
    output_type=_RETRIEVALDEALRECORDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_USERSERVICE)

DESCRIPTOR.services_by_name['UserService'] = _USERSERVICE

# @@protoc_insertion_point(module_scope)
